//[mahjong-utils](../../../index.md)/[mahjongutils.hora](../index.md)/[HoraOptions](index.md)/[aotenjou](aotenjou.md)

# aotenjou

[common]\
val [aotenjou](aotenjou.md): [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html)

是否为青天井规则
